@@ -1,9 +1,11 @@
+#define SYNC_SIZE	600	/* has to be smaller than CD_FRAMESAMPLES */
+
 extern long waitforsignal;	/* flag: wait for any audio response */
 
 extern short undersampling;	/* conversion factor */
 extern short samples_to_do;	/* loop variable for conversion */
 extern int Halved;		/* interpolate due to non integral divider */
 extern int jitterShift;		/* track accumulated jitter */
-long SaveBuffer (unsigned char *p, long channels, 
-                 unsigned long SecsToDo, unsigned long *BytesDone, 
-		 unsigned long TotalSecs);
+long SaveBuffer __PR((UINT4 *p,
+                 unsigned long SecsToDo, unsigned long *BytesDone));
+unsigned char *synchronize __PR((UINT4 *p, unsigned SamplesToDo, unsigned TotSamplesDone));
